<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">
<context>
    <name>dde::hotspotplugin::HotspotPlugin</name>
    <message>
        <source>hotspot</source>
        <translation>точка доступа</translation>
    </message>
    <message>
        <source>Hotspot is unsupported</source>
        <translation>Точка доступа не поддерживается</translation>
    </message>
    <message>
        <source>Personal Hotspot On</source>
        <translation>Персональная точка доступа включена</translation>
    </message>
    <message>
        <source>Personal Hotspot Off</source>
        <translation>Персональная точка доступа выключена</translation>
    </message>
    <message>
        <source>Wireless Device is Unavailable</source>
        <translation>Беспроводные устройства недоступны</translation>
    </message>
</context>
<context>
    <name>dde::hotspotplugin::QuickPanel</name>
    <message>
        <source>HotSpot</source>
        <translation>Точка доступа</translation>
    </message>
</context>
</TS>